xrheed
======

.. automodule:: xrheed
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
----------

.. autosummary::
   :toctree: generated
   :recursive:
   
   loaders
   plugins
   preparation
   conversion
   kinematics
   plotting
   xarray_accessors


